@@ -17,6 +17,9 @@
 # CAM签名/鉴权错误。
 AUTHFAILURE = 'AuthFailure'
 
+# 授权无效。
+AUTHFAILURE_INVALIDAUTHORIZATION = 'AuthFailure.InvalidAuthorization'
+
 # 子账号无权限。
 AUTHFAILURE_SUBACCOUNTDENIED = 'AuthFailure.SubAccountDenied'
 
@@ -68,6 +71,9 @@ FAILEDOPERATION_DELETEAUDITFAILERROR = 'FailedOperation.DeleteAuditFailError'
 # 查询数据库代理失败。
 FAILEDOPERATION_DESCRIBEPROXYGROUPERROR = 'FailedOperation.DescribeProxyGroupError'
 
+# 不支持当前操作。
+FAILEDOPERATION_FAILEDOPERATIONERROR = 'FailedOperation.FailedOperationError'
+
 # 获取权限错误。
 FAILEDOPERATION_GETPRIVILEGEERROR = 'FailedOperation.GetPrivilegeError'
 
@@ -95,6 +101,9 @@ FAILEDOPERATION_PROXYGROUPSTATUSERROR = 'FailedOperation.ProxyGroupStatusError'
 # 查询日志失败。
 FAILEDOPERATION_QUERYLOGERROR = 'FailedOperation.QueryLogError'
 
+# 代理创建中或则已存在，请勿重复创建。
+FAILEDOPERATION_REPEATCREATEPROXYERROR = 'FailedOperation.RepeatCreateProxyError'
+
 # 后台请求服务异常，请您联系客服解决。
 FAILEDOPERATION_RESPONSEVALUEERROR = 'FailedOperation.ResponseValueError'
 
@@ -113,6 +122,12 @@ FAILEDOPERATION_TIMEOUTERROR = 'FailedOperation.TimeoutError'
 # 类型错误，无法执行该操作。
 FAILEDOPERATION_TYPEINCONFLICT = 'FailedOperation.TypeInConflict'
 
+# 该IP已被占用。
+FAILEDOPERATION_VPCIPINUSEERROR = 'FailedOperation.VpcIpInUseError'
+
+# 子网中不存在该IP
+FAILEDOPERATION_VPCIPNOTINSUBNETERROR = 'FailedOperation.VpcIpNotInSubnetError'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -206,6 +221,9 @@ INTERNALERROR_INTERNALSERVICEERRORERR = 'InternalError.InternalServiceErrorErr'
 # json解析失败。
 INTERNALERROR_JSONERROR = 'InternalError.JSONError'
 
+# 开通加密失败。
+INTERNALERROR_KMSERROR = 'InternalError.KmsError'
+
 # 网络错误。
 INTERNALERROR_NETWORKERROR = 'InternalError.NetworkError'
 
@@ -359,6 +377,9 @@ MISSINGPARAMETER_MISSINGPARAMERROR = 'MissingParameter.MissingParamError'
 # 操作被拒绝。
 OPERATIONDENIED = 'OperationDenied'
 
+# 云账号权限不足，不支持该操作。
+OPERATIONDENIED_ACCOUNTOPERATIONDENIED = 'OperationDenied.AccountOperationDenied'
+
 # 实例正在执行其他任务。
 OPERATIONDENIED_ACTIONINPROCESS = 'OperationDenied.ActionInProcess'
 
@@ -449,12 +470,24 @@ OPERATIONDENIED_NOTSUPPORTBASIC = 'OperationDenied.NotSupportBasic'
 # 不支持修改本地root账号host信息。
 OPERATIONDENIED_NOTSUPPORTMODIFYLOCALROOTHOSTERROR = 'OperationDenied.NotSupportModifyLocalRootHostError'
 
+# 操作拒绝。
+OPERATIONDENIED_OPERATIONDENIEDERROR = 'OperationDenied.OperationDeniedError'
+
 # 当前有其他订单正在处于下单过程中，请稍后重试。
 OPERATIONDENIED_OTHERODERINPROCESS = 'OperationDenied.OtherOderInProcess'
 
 # 资源配额超限。
 OPERATIONDENIED_OVERQUOTA = 'OperationDenied.OverQuota'
 
+# 代理地址超限。
+OPERATIONDENIED_PROXYADDRESSLIMITERROR = 'OperationDenied.ProxyAddressLimitError'
+
+# 代理地址未找到。
+OPERATIONDENIED_PROXYADDRESSNOTFUND = 'OperationDenied.ProxyAddressNotFund'
+
+# 代理节点超限。
+OPERATIONDENIED_PROXYNODECOUNTLIMITERROR = 'OperationDenied.ProxyNodeCountLimitError'
+
 # 数据库代理升级任务中，不允许该操作。
 OPERATIONDENIED_PROXYUPGRADETASKSTATUSERROR = 'OperationDenied.ProxyUpgradeTaskStatusError'
 
@@ -467,6 +500,9 @@ OPERATIONDENIED_SUBACCOUNTOPERATIONDENIED = 'OperationDenied.SubAccountOperation
 # 该实例暂不支持退款。
 OPERATIONDENIED_UNSUPPORTREFUNDERROR = 'OperationDenied.UnSupportRefundError'
 
+# 不支持创建代理地址。
+OPERATIONDENIED_UNSUPPORTCREATEADDRESSERROR = 'OperationDenied.UnsupportCreateAddressError'
+
 # 不支持开通审计。
 OPERATIONDENIED_UNSUPPORTOPENAUDITERROR = 'OperationDenied.UnsupportOpenAuditError'
 
@@ -494,6 +530,9 @@ RESOURCENOTFOUND = 'ResourceNotFound'
 # 未找到数据库实例，请确认您的实例状态是否正常。
 RESOURCENOTFOUND_CDBINSTANCENOTFOUNDERROR = 'ResourceNotFound.CdbInstanceNotFoundError'
 
+# 高可用版实例不存在。
+RESOURCENOTFOUND_INSTANCENOTFOUNDERROR = 'ResourceNotFound.InstanceNotFoundError'
+
 # 该实例不存在。
 RESOURCENOTFOUND_INSTANCENOTFUNDERROR = 'ResourceNotFound.InstanceNotFundError'
 
